from osm_field.widgets import _get_css, _get_js
from wagtail.wagtailcore import hooks
from django.conf import settings
from django.utils.html import format_html_join


@hooks.register('insert_editor_js')
def editor_js():
    """
    Add extra JS files to the admin
    """
    js_files = _get_js(settings.DEBUG)
    js_includes = format_html_join(
        '\n',
        '<script type="text/javascript" src="{0}{1}"></script>',
        ((settings.STATIC_URL, filename) for filename in js_files)
    )

    return js_includes


@hooks.register('insert_editor_css')
def editor_css():
    """
    Add extra JS files to the admin
    """
    css_files = _get_css(settings.DEBUG) + ['wagtailosm/css/wagtailadmin.css']
    css_includes = format_html_join(
        '\n',
        '<link rel="stylesheet" href="{0}{1}">',
        ((settings.STATIC_URL, filename) for filename in css_files)
    )

    return css_includes



#!/usr/bin/env python

import os
import sys

try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup



readme = open('README.rst').read()
doclink = """
Documentation
-------------

The full documentation is at http://wagtailosm.rtfd.org."""
history = open('HISTORY.rst').read().replace('.. :changelog:', '')

import wagtailosm

setup(
    name='wagtailosm',
    version=wagtailosm.__version__,
    description='Open Street Map integration for Wagtail',
    long_description=readme + '\n\n' + doclink + '\n\n' + history,
    author='Benjamin Bach',
    author_email='benjamin@overtag.dk',
    url='https://github.com/benjaoming/wagtailosm',
    packages=[
        'wagtailosm',
    ],
    package_dir={'wagtailosm': 'wagtailosm'},
    include_package_data=True,
    install_requires=[
        'django-osm-field==0.3.0',
    ],
    license='MIT',
    zip_safe=False,
    keywords='wagtailosm',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Natural Language :: English',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: Implementation :: PyPy',
    ],
)



"""
Tests for `wagtailosm` module.
"""
import pytest
from wagtailosm import wagtailosm


class TestWagtailosm(object):

    @classmethod
    def setup_class(cls):
        pass

    def test_something(self):
        pass

    @classmethod
    def teardown_class(cls):
        pass
